==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/el/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Ένας χρήστης έχει ακυρώσει μια αίτηση στοιχείο στην ιστοσελίδα',
    'a_user_requested' => 'Ο χρήστης έχει ζητήσει ένα στοιχείο στην ιστοσελίδα',
    'accessory_name' => 'Όνομα ανταλλακτικού:',
    'additional_notes' => 'Πρόσθετες σημειώσεις:',
    'admin_has_created' => 'Ένας διαχειριστής έχει δημιουργήσει ένα λογαριασμό για εσάς στην: web ιστοσελίδα.',
    'asset' => 'Πάγιο:',
    'asset_name' => 'Όνομα του περιουσιακού στοιχείου:',
    'asset_requested' => 'Πάγιο αίτήθηκε',
    'asset_tag' => 'Ετικέτα παγίων:',
    'assigned_to' => 'Ανατέθηκε στον',
    'best_regards' => 'Τις καλύτερες ευχές,',
    'canceled' => 'Ακυρωμένο:',
    'checkin_date' => 'Ημερομηνία άφιξης:',
    'checkout_date' => 'Ημερομηνία αποχώρησης:',
    'click_to_confirm' => 'Κάντε κλικ στον παρακάτω σύνδεσμο για να επιβεβαιώσετε τον λογαριασμό σας στο διαδίκτυο:',
    'click_on_the_link_accessory' => 'Κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε λάβει το αξεσουάρ.',
    'click_on_the_link_asset' => 'Κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε λάβει το στοιχείο.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Τρέχουσα ποσότητα',
    'Days' => 'Ημέρες',
    'days' => 'Ημέρες',
    'expecting_checkin_date' => 'Αναμενόμενη ημερομηνία checkin:',
    'expires' => 'Λήξη',
    'Expiring_Assets_Report' => 'Αναφορά λήξης παγίων.',
    'Expiring_Licenses_Report' => 'Αναφορά λήξης αδειών.',
    'hello' => 'Γεια',
    'hi' => 'Γεια σας',
    'i_have_read' => 'Έχω διαβάσει και συμφωνώ με τους όρους χρήσης, και έχω λάβει αυτό το στοιχείο.',
    'item' => 'Αντικείμενο:',
    'Item_Request_Canceled' => 'Αίτηση στοιχείου ακυρώθηκε',
    'Item_Requested' => 'Στοιχείο που ζητήθηκε',
    'link_to_update_password' => 'Κάντε κλικ στον παρακάτω σύνδεσμο για να ενημερώσετε τον κωδικό: web:',
    'login_first_admin' => 'Συνδεθείτε στη νέα σας εγκατάσταση Snipe-IT χρησιμοποιώντας τα παρακάτω διαπιστευτήρια:',
    'login' => 'Σύνδεση:',
    'Low_Inventory_Report' => 'Αναφορά χαμηλού αποθέματος',
    'min_QTY' => 'Ελάχιστη ποσότητα',
    'name' => 'Όνομα',
    'new_item_checked' => 'Ένα νέο στοιχείο έχει ελεγχθεί με το όνομά σας, οι λεπτομέρειες είναι παρακάτω.',
    'password' => 'Κωδικός:',
    'password_reset' => 'Επαναφορά κωδικού πρόσβασης',

    'read_the_terms' => 'Παρακαλώ διαβάστε του παρακάτω όρους.',
    'read_the_terms_and_click' => 'Διαβάστε τους παρακάτω όρους χρήσης και κάντε κλικ στον σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε διαβάσει και συμφωνήσετε με τους όρους χρήσης και έχετε λάβει το στοιχείο.',
    'requested' => 'Ζητήθηκαν:',
    'reset_link' => 'Αποστολή συνδέσμου ακύρωσης κωδικού',
    'reset_password' => 'Κάντε κλικ εδώ για να επαναφέρετε τον κωδικό πρόσβασής σας:',
    'serial' => 'Serial',
    'supplier' => 'Προμηθευτές',
    'tag' => 'Ετικέτα',
    'test_email' => 'Έλεγχος email για Snipe-IT',
    'test_mail_text' => 'Πρόκειται για μια δοκιμή από το σύστημα διαχείρισης περιουσιακών στοιχείων της Snipe-IT. Αν το έχετε, το mail λειτουργεί :)',
    'the_following_item' => 'Το παρακάτω στοιχείο έχει ελεγχθεί:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Για να επαναφέρετε τον κωδικό πρόσβασης στον ιστό, συμπληρώστε αυτήν τη φόρμα:',
    'type' => 'Τύπος',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Καλώς ήρθατε, %name',
    'welcome_to' => 'Καλώς ήλθατε στο!',
    'your_credentials' => 'Τα διαπιστευτήρια σας Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/el/mail.php <==
<?php

return [
    'a_user_canceled' => 'Ένας χρήστης έχει ακυρώσει μια αίτηση στοιχείο στην ιστοσελίδα',
    'a_user_requested' => 'Ο χρήστης έχει ζητήσει ένα στοιχείο στην ιστοσελίδα',
    'accessory_name' => 'Όνομα ανταλλακτικού:',
    'additional_notes' => 'Πρόσθετες σημειώσεις:',
    'admin_has_created' => 'Ένας διαχειριστής έχει δημιουργήσει ένα λογαριασμό για εσάς στην: web ιστοσελίδα.',
    'asset' => 'Πάγιο:',
    'asset_name' => 'Όνομα του περιουσιακού στοιχείου:',
    'asset_requested' => 'Πάγιο αίτήθηκε',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Ανατέθηκε στον',
    'best_regards' => 'Τις καλύτερες ευχές,',
    'canceled' => 'Ακυρωμένο:',
    'checkin_date' => 'Ημερομηνία άφιξης:',
    'checkout_date' => 'Ημερομηνία αποχώρησης:',
    'click_to_confirm' => 'Κάντε κλικ στον παρακάτω σύνδεσμο για να επιβεβαιώσετε τον λογαριασμό σας στο διαδίκτυο:',
    'click_on_the_link_accessory' => 'Κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε λάβει το αξεσουάρ.',
    'click_on_the_link_asset' => 'Κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε λάβει το στοιχείο.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Τρέχουσα ποσότητα',
    'Days' => 'Ημέρες',
    'days' => 'Ημέρες',
    'expecting_checkin_date' => 'Αναμενόμενη ημερομηνία checkin:',
    'expires' => 'Λήξη',
    'Expiring_Assets_Report' => 'Αναφορά λήξης παγίων.',
    'Expiring_Licenses_Report' => 'Αναφορά λήξης αδειών.',
    'hello' => 'Γεια',
    'hi' => 'Γεια σας',
    'i_have_read' => 'Έχω διαβάσει και συμφωνώ με τους όρους χρήσης, και έχω λάβει αυτό το στοιχείο.',
    'item' => 'Αντικείμενο:',
    'Item_Request_Canceled' => 'Αίτηση στοιχείου ακυρώθηκε',
    'Item_Requested' => 'Στοιχείο που ζητήθηκε',
    'link_to_update_password' => 'Κάντε κλικ στον παρακάτω σύνδεσμο για να ενημερώσετε τον κωδικό: web:',
    'login_first_admin' => 'Συνδεθείτε στη νέα σας εγκατάσταση Snipe-IT χρησιμοποιώντας τα παρακάτω διαπιστευτήρια:',
    'login' => 'Σύνδεση:',
    'Low_Inventory_Report' => 'Αναφορά χαμηλού αποθέματος',
    'min_QTY' => 'Ελάχιστη ποσότητα',
    'name' => 'Όνομα',
    'new_item_checked' => 'Ένα νέο στοιχείο έχει ελεγχθεί με το όνομά σας, οι λεπτομέρειες είναι παρακάτω.',
    'password' => 'Κωδικός:',
    'password_reset' => 'Επαναφορά κωδικού πρόσβασης',

    'read_the_terms' => 'Παρακαλώ διαβάστε του παρακάτω όρους.',
    'read_the_terms_and_click' => 'Διαβάστε τους παρακάτω όρους χρήσης και κάντε κλικ στον σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε διαβάσει και συμφωνήσετε με τους όρους χρήσης και έχετε λάβει το στοιχείο.',
    'requested' => 'Ζητήθηκαν:',
    'reset_link' => 'Αποστολή συνδέσμου ακύρωσης κωδικού',
    'reset_password' => 'Κάντε κλικ εδώ για να επαναφέρετε τον κωδικό πρόσβασής σας:',
    'serial' => 'Serial',
    'supplier' => 'Προμηθευτές',
    'tag' => 'Ετικέτα',
    'test_email' => 'Έλεγχος email για Snipe-IT',
    'test_mail_text' => 'Πρόκειται για μια δοκιμή από το σύστημα διαχείρισης περιουσιακών στοιχείων της Snipe-IT. Αν το έχετε, το mail λειτουργεί :)',
    'the_following_item' => 'Το παρακάτω στοιχείο έχει ελεγχθεί:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Για να επαναφέρετε τον κωδικό πρόσβασης στον ιστό, συμπληρώστε αυτήν τη φόρμα:',
    'type' => 'Τύπος',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Καλώς ήρθατε, %name',
    'welcome_to' => 'Καλώς ήλθατε στο!',
    'your_credentials' => 'Τα διαπιστευτήρια σας Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
